TCPNetworkDecoder

Struct TCPNetworkDecoder 

pub struct TCPNetworkDecoder<R: AsyncRead + Unpin> {
    reader: DecryptionReader<R>,
    compression: Option<NonZeroU32>,
}
Decoder: Client -> Server Supports ZLib decoding/decompression Supports Aes128 Encryption

Fields

reader: DecryptionReader<R>compression: Option<NonZeroU32>

Implementations

Source

impl<R: AsyncRead + Unpin> TCPNetworkDecoder<R>

pub const fn new(reader: R) -> Self

Creates a new TCPNetworkDecoder.

pub const fn set_compression(&mut self, threshold: NonZeroU32)

Sets the compression threshold for the decoder.

pub fn set_encryption(&mut self, key: &[u8; 16])

NOTE: Encryption can only be set; a minecraft stream cannot go back to being unencrypted

Panics
  • If the reader is already decrypting data.
  • If the key is invalid.
pub async fn get_raw_packet(&mut self) -> Result<RawPacket, PacketError>

Gets a raw packet from the stream.

Errors
  • If the packet length is invalid.
  • If the packet is too long.
  • If the packet is not compressed when it should be.
  • If the packet fails to decompress.